[![Python Versions](https://img.shields.io/pypi/pyversions/statista.png)](https://img.shields.io/pypi/pyversions/statista)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/MAfarrag/Hapi.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/MAfarrag/Hapi/context:python)



![GitHub last commit](https://img.shields.io/github/last-commit/MAfarrag/statista)
![GitHub forks](https://img.shields.io/github/forks/MAfarrag/statista?style=social)
![GitHub Repo stars](https://img.shields.io/github/stars/MAfarrag/statista?style=social)



statista - Statistics package
=====================================================================
**statista** is a statistics package

statista

Main Features
-------------
  - 


Future work
-------------
  - 



Installing statista
===============

Installing `statista` from the `conda-forge` channel can be achieved by:

```
conda install -c conda-forge statista
```

It is possible to list all of the versions of `statista` available on your platform with:

```
conda search statista --channel conda-forge
```

## Install from Github
to install the last development to time you can install the library from github
```
pip install git+https://github.com/MAfarrag/statista
```

## pip
to install the last release you can easly use pip
```
pip install statista==0.1.0
```

Quick start
===========

```
  >>> import statista
```

[other code samples](https://statista.readthedocs.io/en/latest/?badge=latest)
